==> formatusb_23.05.01.tar.xz: formatusb/translations/formatusb_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nome_do_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Show all devices</source>
        <translation>Exibir todos os dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>Defaults</source>
        <translation>Padrões</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>msdos</source>
        <translation>msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>gpt</source>
        <translation>gpt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecione o Dispositivo USB a ser Formatado&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Show partitions</source>
        <translation>Exibir as partições</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>fat32</source>
        <translation>fat32</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>Refresh drive list</source>
        <translation>Atualizar a lista de dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <source>USB-DATA</source>
        <translation>USB-DE-DADOS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="156"/>
        <source>File System Label</source>
        <translation>Descrição do Sistema de Arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Partition Table Type</source>
        <translation>Tipo de Tabela da Partição</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Format successful!</source>
        <translation>A formatação foi bem-sucedida!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Failure</source>
        <translation>Falha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Error encountered in the Format process</source>
        <translation>Um erro foi encontrado no processo de formatação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Please select a USB device to write to</source>
        <translation>Por favor, selecione o dispositivo USB para formatar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Estas ações irão destruir (apagar) todos os dados no dispositivo

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Do you wish to continue?</source>
        <translation>Você quer continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Program for formatting USB devices</source>
        <translation>Programa para Formatar Dispositivos USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <location filename="../about.cpp" line="45"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>

==> formatusb_23.07.01.tar.xz: formatusb/translations/formatusb_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Nome_do_Programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Show all devices</source>
        <translation>Exibir todos os dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>Defaults</source>
        <translation>Padrões</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>msdos</source>
        <translation>msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>gpt</source>
        <translation>gpt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Selecione o Dispositivo USB a ser Formatado&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Show partitions</source>
        <translation>Exibir as partições</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>fat32</source>
        <translation>fat32</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>Refresh drive list</source>
        <translation>Atualizar a lista de dispositivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <source>USB-DATA</source>
        <translation>USB-DE-DADOS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="156"/>
        <source>File System Label</source>
        <translation>Descrição do Sistema de Arquivos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="163"/>
        <source>Partition Table Type</source>
        <translation>Tipo de Tabela da Partição</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="222"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>Display help </source>
        <translation>Exibir ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="312"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="178"/>
        <source>Format successful!</source>
        <translation>A formatação foi bem-sucedida!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Failure</source>
        <translation>Falha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>Error encountered in the Format process</source>
        <translation>Um erro foi encontrado no processo de formatação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Error</source>
        <translation>Ocorreu um Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Please select a USB device to write to</source>
        <translation>Por favor, selecione o dispositivo USB para formatar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Estas ações irão destruir (apagar) todos os dados no dispositivo

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="216"/>
        <source>Do you wish to continue?</source>
        <translation>Você quer continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Program for formatting USB devices</source>
        <translation>Programa para Formatar Dispositivos USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Invalid Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <location filename="../about.cpp" line="45"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>
